@@ -4,7 +4,7 @@
 # 
 # Copyright (C) 2006-2008 by Jason Field <jason@jasonfield.com>
 # Copyright (C) 2007-2008 by Bruce van der Kooij <brucevdkooij@gmail.com>
-# Copyright (C) 2008-2008 by Adam Plumb <adamplumb@gmail.com>
+# Copyright (C) 2008-2010 by Adam Plumb <adamplumb@gmail.com>
 # 
 # RabbitVCS is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,12 +23,12 @@
 import unittest
 import doctest
 
-import lib.helper
+import rabbitvcs.util.helper
 
 if __name__ == "__main__":
     suite = unittest.TestSuite()
     
-    for module in (lib.helper,):
+    for module in (rabbitvcs.util.helper,):
         suite.addTest(doctest.DocTestSuite(module))
         runner = unittest.TextTestRunner()
         runner.run(suite)
