@@ -72,11 +72,13 @@ class Commit(InterfaceView, GtkContextMenuCaller):
 
         self.base_dir = base_dir
         self.vcs = rabbitvcs.vcs.VCS()
+        self.items = []
 
         self.files_table = rabbitvcs.ui.widget.Table(
             self.get_widget("files_table"),
             [gobject.TYPE_BOOLEAN, rabbitvcs.ui.widget.TYPE_PATH, 
-                gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING], 
+                gobject.TYPE_STRING, rabbitvcs.ui.widget.TYPE_STATUS,
+                gobject.TYPE_STRING], 
             [rabbitvcs.ui.widget.TOGGLE_BUTTON, _("Path"), _("Extension"), 
                 _("Text Status"), _("Property Status")],
             filters=[{
@@ -98,7 +100,7 @@ class Commit(InterfaceView, GtkContextMenuCaller):
             }
         )
         self.files_table.allow_multiple()
-
+        self.get_widget("toggle_show_unversioned").set_active(not self.SHOW_UNVERSIONED)
         self.message = rabbitvcs.ui.widget.TextView(
             self.get_widget("message"),
             (message and message or "")
@@ -128,7 +130,6 @@ class Commit(InterfaceView, GtkContextMenuCaller):
 
         gtk.gdk.threads_enter()
         self.populate_files_table()
-        self.get_widget("status").set_text(_("Found %d item(s)") % len(self.items))
         gtk.gdk.threads_leave()
 
     # Overrides the GtkContextMenuCaller method
@@ -179,15 +180,14 @@ class Commit(InterfaceView, GtkContextMenuCaller):
     #
     # Event handlers
     #
-    
-    def on_destroy(self, widget):
-        self.destroy()
-        
-    def on_cancel_clicked(self, widget, data=None):
-        self.close()
-        
+    def on_refresh_clicked(self, widget):
+        self.initialize_items()        
+
     def on_key_pressed(self, widget, data):
-        if (data.state & (gtk.gdk.SHIFT_MASK | gtk.gdk.CONTROL_MASK) and 
+        if InterfaceView.on_key_pressed(self, widget, data):
+            return True
+
+        if (data.state & (gtk.gdk.CONTROL_MASK) and 
                 gtk.gdk.keyval_name(data.keyval) == "Return"):
             self.on_ok_clicked(widget)
             return True
@@ -242,6 +242,7 @@ class Commit(InterfaceView, GtkContextMenuCaller):
         """
         
         self.files_table.clear()
+        n = 0
         for item in self.items:
             if item.path in self.changes:
                 checked = self.changes[item.path]
@@ -251,6 +252,7 @@ class Commit(InterfaceView, GtkContextMenuCaller):
             if not self.should_item_be_visible(item):
                 continue
 
+            n += 1
             self.files_table.append([
                 checked,
                 item.path, 
@@ -258,6 +260,7 @@ class Commit(InterfaceView, GtkContextMenuCaller):
                 item.simple_content_status(),
                 item.simple_metadata_status()
             ])
+        self.get_widget("status").set_text(_("Found %d item(s)") % n)
 
 class SVNCommit(Commit):
     def __init__(self, paths, base_dir=None, message=None):
@@ -309,12 +312,17 @@ class SVNCommit(Commit):
         self.action.append(
             rabbitvcs.util.helper.save_log_message, 
             self.message.get_text()
-        )
-        self.action.append(self.vcs.svn().commit, items, self.message.get_text(), recurse=recurse)
-        self.action.append(self.action.set_status, _("Completed Commit"))
+        ),
+        self.action.append(self.do_commit, items, recurse)
         self.action.append(self.action.finish)
         self.action.start()
 
+    def do_commit(self, items, recurse):
+        # pysvn.Revision
+        revision = self.vcs.svn().commit(items, self.message.get_text(), recurse=recurse)
+        
+        self.action.set_status(_("Completed Commit") + " at Revision: " + str(revision.number))
+
     def on_files_table_toggle_event(self, row, col):
         # Adds path: True/False to the dict
         self.changes[row[1]] = row[col]
@@ -360,7 +368,7 @@ class GitCommit(Commit):
         self.action.append(self.action.set_header, _("Commit"))
         self.action.append(self.action.set_status, _("Running Commit Command..."))
         self.action.append(
-            rabbitvcs.util.helper.save_log_message, 
+            rabbitvcs.util.helper.save_log_message,
             self.message.get_text()
         )
         self.action.append(
@@ -369,7 +377,7 @@ class GitCommit(Commit):
         )
         self.action.append(self.action.set_status, _("Completed Commit"))
         self.action.append(self.action.finish)
-        self.action.start()
+        self.action.start() 
 
     def on_files_table_toggle_event(self, row, col):
         # Adds path: True/False to the dict
