@@ -46,6 +46,8 @@ _ = gettext.gettext
 DATETIME_FORMAT = rabbitvcs.util.helper.LOCAL_DATETIME_FORMAT
 
 REVISION_LABEL = _("Revision")
+DATE_LABEL = _("Date")
+AUTHOR_LABEL = _("Author")
 
 def revision_grapher(history):
     """
@@ -105,7 +107,8 @@ class Log(InterfaceView):
     selected_rows = []
     selected_row = []
     paths_selected_rows = []
-    
+    display_items = []
+
     limit = 100
 
     def __init__(self, path):
@@ -120,6 +123,7 @@ class Log(InterfaceView):
         self.get_widget("Log").set_title(_("Log - %s") % path)
         self.vcs = rabbitvcs.vcs.VCS()
 
+        self.filter_text = None
         self.path = path
         self.cache = LogCache()
 
@@ -138,6 +142,7 @@ class Log(InterfaceView):
         )
 
         self.stop_on_copy = False
+        self.revision_clipboard = gtk.Clipboard()
 
     #
     # UI Signal Callback Methods
@@ -154,6 +159,13 @@ class Log(InterfaceView):
 
         self.close()
     
+    def on_key_pressed(self, widget, data):
+        InterfaceView.on_key_pressed(self, widget, data)
+        if (data.state & gtk.gdk.CONTROL_MASK and
+            gtk.gdk.keyval_name(data.keyval).lower() == "c"):
+            if len(self.revisions_table.get_selected_rows()) > 0:
+                self.copy_revision_text()
+
     def on_stop_on_copy_toggled(self, widget):
         self.stop_on_copy = self.get_widget("stop_on_copy").get_active()
         if not self.is_loading:
@@ -164,12 +176,28 @@ class Log(InterfaceView):
         self.cache.empty()
         self.load()
 
+    
+    def on_search(self, widget):
+        tb = self.get_widget("search_buffer")
+        self.filter_text = tb.get_text(tb.get_start_iter(), tb.get_end_iter()).lower()
+
+        self.refresh()
+
     #
     # Revisions table callbacks
     #
 
+    # In this UI, we have an ability to filter and display only certain items.
+    def get_displayed_row_items(self, col):
+        items = []
+        for row in self.selected_rows:
+            items.append(self.display_items[row][col])
+        
+        return items
+
     def on_revisions_table_row_activated(self, treeview, event, col):
-        paths = self.revisions_table.get_selected_row_items(1)
+        paths = self.revisions_table.get_displayed_row_items(1)
+
         rabbitvcs.util.helper.launch_diff_tool(*paths)
 
     def on_revisions_table_mouse_event(self, treeview, data=None):
@@ -193,8 +221,8 @@ class Log(InterfaceView):
 
     def on_paths_table_row_activated(self, treeview, data=None, col=None):
         try:
-            revision1 = unicode(self.revision_items[self.revisions_table.get_selected_rows()[0]].revision)
-            revision2 = unicode(self.revision_items[self.revisions_table.get_selected_rows()[0]+1].revision)
+            revision1 = unicode(self.display_items[self.revisions_table.get_selected_rows()[0]].revision)
+            revision2 = unicode(self.display_items[self.revisions_table.get_selected_rows()[0]+1].revision)
             path_item = self.paths_table.get_row(self.paths_table.get_selected_rows()[0])[1]
             url = self.root_url + path_item
             self.view_diff_for_path(url, unicode(revision1), unicode(revision2), sidebyside=True)
@@ -209,18 +237,21 @@ class Log(InterfaceView):
         revisions = []
         for row in self.revisions_table.get_selected_rows():
             line = {
-                "revision": self.revision_items[row].revision,
-                "author": self.revision_items[row].author,
-                "message": self.revision_items[row].message,
-                "parents": self.revision_items[row].parents
+                "revision": self.display_items[row].revision,
+                "author": self.display_items[row].author,
+                "message": self.display_items[row].message
             }
+
+            if self.display_items[row].parents:
+                line["parents"] = self.display_items[row].parents
+
             try:
-                line["next_revision"] = self.revision_items[row+1].revision
+                line["next_revision"] = self.display_items[row+1].revision
             except IndexError,e:
                 pass
 
             try:
-                line["previous_revision"] = self.revision_items[row-1].revision
+                line["previous_revision"] = self.display_items[row-1].revision
             except IndexError,e:
                 pass          
                       
@@ -278,17 +309,17 @@ class Log(InterfaceView):
         revisions = []
         for row in self.revisions_table.get_selected_rows():
             line = {
-                "revision": self.revision_items[row].revision,
-                "author": self.revision_items[row].author,
-                "message": self.revision_items[row].message
+                "revision": self.display_items[row].revision,
+                "author": self.display_items[row].author,
+                "message": self.display_items[row].message
             }
             try:
-                line["next_revision"] = self.revision_items[row+1].revision
+                line["next_revision"] = self.display_items[row+1].revision
             except IndexError,e:
                 pass
 
             try:
-                line["previous_revision"] = self.revision_items[row-1].revision
+                line["previous_revision"] = self.display_items[row-1].revision
             except IndexError,e:
                 pass          
                       
@@ -325,22 +356,30 @@ class Log(InterfaceView):
         return vcs
 
 class SVNLog(Log):
-    def __init__(self, path):
+    def __init__(self, path, merge_candidate_revisions=None):
         Log.__init__(self, path)
                 
         self.svn = self.vcs.svn()
+        self.merge_candidate_revisions = merge_candidate_revisions
 
         self.revisions_table = rabbitvcs.ui.widget.Table(
             self.get_widget("revisions_table"),
             [gobject.TYPE_STRING, gobject.TYPE_STRING, 
-                gobject.TYPE_STRING, gobject.TYPE_STRING], 
+                gobject.TYPE_STRING, gobject.TYPE_STRING,
+                rabbitvcs.ui.widget.TYPE_HIDDEN],
             [_("Revision"), _("Author"), 
-                _("Date"), _("Message")],
+                _("Date"), _("Message"),
+                _("Color")],
             callbacks={
                 "mouse-event":   self.on_revisions_table_mouse_event
             }
         )
 
+        for i in range(4):
+            column = self.revisions_table.get_column(i)
+            cell = column.get_cell_renderers()[0]
+            column.add_attribute(cell, 'foreground', 4)
+
         self.paths_table = rabbitvcs.ui.widget.Table(
             self.get_widget("paths_table"),
             [gobject.TYPE_STRING, gobject.TYPE_STRING, 
@@ -410,30 +449,56 @@ class SVNLog(Log):
         if self.rev_start > self.rev_max:
             self.rev_max = self.rev_start
         
+        self.display_items = []
+
+        for item in self.revision_items:
+            msg = cgi.escape(item.message).lower()
+
+            should_add = not self.filter_text
+            should_add = should_add or msg.find(self.filter_text) > -1
+            should_add = should_add or item.author.lower().find(self.filter_text) > -1
+            should_add = should_add or str(item.revision).lower().find(self.filter_text) > -1
+            should_add = should_add or str(item.date).lower().find(self.filter_text) > -1
+
+            if should_add:
+                self.display_items.append(item)
+
         self.set_start_revision(self.rev_start)
         self.set_end_revision(self.rev_end)
 
-        for item in self.revision_items:
-            msg = cgi.escape(rabbitvcs.util.helper.format_long_text(item.message, 80))
+        self.check_previous_sensitive()
+        self.check_next_sensitive()
 
-            self.revisions_table.append([
-                unicode(item.revision),
-                item.author,
-                rabbitvcs.util.helper.format_datetime(item.date),
-                msg
-            ])
+        for item in self.display_items:
+            msg = cgi.escape(rabbitvcs.util.helper.format_long_text(item.message, 80))
+            rev = item.revision
+            color = "#000000"
+            if (self.merge_candidate_revisions != None and
+                int(rev.short()) not in self.merge_candidate_revisions):
+                color = "#c9c9c9"
+
+            self.populate_table(rev, item.author, item.date, msg, color)
 
             # Stop on copy after adding the item to the table
             # so the user can look at the item that was copied
             if self.stop_on_copy:
                 for path in item.changed_paths:
                     if path.copy_from_path or path.copy_from_revision:
+                        self.set_loading(False)
                         return
-            
-        self.check_previous_sensitive()
-        self.check_next_sensitive()
+
         self.set_loading(False)
 
+    def populate_table(self, revision, author, date, msg, color):
+        self.revisions_table.append([
+            unicode(revision),
+            author,
+            rabbitvcs.util.helper.format_datetime(date),
+            msg,
+            color
+        ])
+
+
     def load(self):
         self.set_loading(True)
 
@@ -467,7 +532,7 @@ class SVNLog(Log):
         )
 
         for row in self.revisions_table.get_selected_rows():
-            item = self.revision_items[row]
+            item = self.display_items[row]
             self.action.append(
                 self.svn.revpropset,
                 prop_name,
@@ -481,20 +546,42 @@ class SVNLog(Log):
         self.action.start()
 
     def on_log_message_edited(self, index, val):
-        self.revision_items[index].message = val
+        self.display_items[index].message = val
         self.revisions_table.set_row_item(index, 3, val)
         self.message.set_text(val)
 
     def on_author_edited(self, index, val):
-        self.revision_items[index].author = val
+        self.display_items[index].author = val
         self.revisions_table.set_row_item(index, 1, val)
 
+    def copy_revision_text(self):
+        text = "" 
+        for selected_row in self.revisions_table.get_selected_rows():
+            item = self.display_items[selected_row]
+            
+            text += "%s: %s\n" % (REVISION_LABEL, unicode(item.revision))
+            text += "%s: %s\n" % (AUTHOR_LABEL, unicode(item.author))
+            text += "%s: %s\n" % (DATE_LABEL, unicode(item.date))
+            text += "%s\n\n"   % item.message
+            if item.changed_paths is not None:
+                for subitem in item.changed_paths:
+                    text += "%s\t%s" % (subitem.action, subitem.path)
+
+                    if subitem.copy_from_path or subitem.copy_from_revision:
+                        text += " (Copied from %s %s)" % (subitem.copy_from_path, subitem.copy_from_revision)
+
+                    text += "\n"
+
+            text += "\n\n\n"
+
+        self.revision_clipboard.set_text(text)
+
     def update_revision_message(self):
         combined_paths = []
         subitems = []
                
         for selected_row in self.revisions_table.get_selected_rows():
-            item = self.revision_items[selected_row]
+            item = self.display_items[selected_row]
             
             if len(self.revisions_table.get_selected_rows()) == 1:
                 self.message.set_text(item.message)
@@ -546,7 +633,7 @@ class SVNLog(Log):
         sensitive = True
         if self.rev_end == 1:
             sensitive = False
-        if len(self.revision_items) <= self.limit:
+        if len(self.revision_items) < self.limit:
             sensitive = False
 
         self.get_widget("next").set_sensitive(sensitive)
@@ -620,15 +707,30 @@ class GitLog(Log):
         self.set_start_revision(self.revision_items[0].revision.short())
         self.set_end_revision(self.revision_items[-1].revision.short())
 
-        grapher = revision_grapher(self.revision_items)
+        self.display_items = []
+
+        for item in self.revision_items:
+            msg = cgi.escape(item.message).lower()
+
+            should_add = not self.filter_text
+            should_add = should_add or msg.find(self.filter_text) > -1
+            should_add = should_add or item.author.lower().find(self.filter_text) > -1
+            should_add = should_add or unicode(item.revision).lower().find(self.filter_text) > -1
+            should_add = should_add or str(item.date).lower().find(self.filter_text) > -1
+
+            if should_add:
+                self.display_items.append(item)
+
+        grapher = revision_grapher(self.display_items)
         max_columns = 1
         for (item, node, in_lines, out_lines) in grapher:
             if max_columns < len(out_lines):
                 max_columns = len(out_lines)
 
-        graph_column = self.revisions_table.get_column(0)
-        cell = graph_column.get_cell_renderers()[0]
-        self.revisions_table.set_column_width(0, 16*max_columns)
+        if not self.filter_text:
+            graph_column = self.revisions_table.get_column(0)
+            cell = graph_column.get_cell_renderers()[0]
+            self.revisions_table.set_column_width(0, 16*max_columns)
 
         index = 0
         for (item, node, in_lines, out_lines) in grapher:
@@ -643,8 +745,12 @@ class GitLog(Log):
                 author = "<b>%s</b>" % author
                 date = "<b>%s</b>" % date            
             
+            graph_render = ()
+            if not self.filter_text:
+                graph_render = (node, in_lines, out_lines)
+
             self.revisions_table.append([
-                (node, in_lines, out_lines),
+                graph_render,
                 revision,
                 author,
                 date,
@@ -675,12 +781,24 @@ class GitLog(Log):
         self.action.append(self.refresh)
         self.action.start()
 
+    def copy_revision_text(self):
+        text = ""
+        for selected_row in self.revisions_table.get_selected_rows():
+            item = self.display_items[selected_row]
+
+            text += "%s: %s\n" % (REVISION_LABEL, unicode(item.revision.short()))
+            text += "%s: %s\n" % (AUTHOR_LABEL, unicode(item.author))
+            text += "%s: %s\n" % (DATE_LABEL, unicode(item.date))
+            text += "%s\n\n" % item.message
+            
+        self.revision_clipboard.set_text(text)
+
     def update_revision_message(self):
         combined_paths = []
         subitems = []
         
         for selected_row in self.revisions_table.get_selected_rows():
-            item = self.revision_items[selected_row]
+            item = self.display_items[selected_row]
 
             if len(self.revisions_table.get_selected_rows()) == 1:
                 self.message.set_text(item.message)
@@ -724,7 +842,7 @@ class GitLog(Log):
 
     def check_next_sensitive(self):
         sensitive = True
-        if len(self.revision_items) <= self.limit:
+        if len(self.revision_items) < self.limit:
             sensitive = False
 
         self.get_widget("next").set_sensitive(sensitive)
@@ -733,13 +851,13 @@ class GitLog(Log):
         self.root_url = self.git.get_repository() + "/"
 
 class SVNLogDialog(SVNLog):
-    def __init__(self, path, ok_callback=None, multiple=False):
+    def __init__(self, path, ok_callback=None, multiple=False, merge_candidate_revisions=None):
         """
         Override the normal SVNLog class so that we can hide the window as we need.
         Also, provide a callback for when the OK button is clicked so that we
         can get some desired data.
         """
-        SVNLog.__init__(self, path)
+        SVNLog.__init__(self, path, merge_candidate_revisions)
         self.ok_callback = ok_callback
         self.multiple = multiple
         
@@ -841,6 +959,17 @@ class MenuUpdateToThisRevision(MenuItem):
     tooltip = _("Update the selected path to this revision")
     icon = "rabbitvcs-update"
 
+class MenuRevertChangesFromThisRevision(MenuItem):
+    identifier = "RabbitVCS::Revert_Changes_From_This_Revision"
+    label = _("Revert changes from this revision")
+    tooltip = _("Update the selected path by reverse merging the changes")
+    icon = "rabbitvcs-revert"    
+
+class MenuCopyClipboard(MenuItem):
+    identifier = "RabbitVCS::Copy_Clipboard"
+    label = _("Copy to clipboard")
+    tooltip = _("Copy to clipboard the full data of these revisions")
+
 class MenuEditAuthor(MenuItem):
     identifier = "RabbitVCS::Edit_Author"
     label = _("Edit author...")
@@ -873,6 +1002,9 @@ class LogTopContextMenuConditions:
     def view_diff_working_copy(self, data=None):
         return (self.vcs.is_in_a_or_a_working_copy(self.path) and len(self.revisions) == 1)
 
+    def copy_clipboard(self, data=None):
+        return (len(self.revisions) > 0)
+
     def view_diff_previous_revision(self, data=None):
         item = self.revisions[0]["revision"]
         return ("previous_revision" in self.revisions[0] and len(self.revisions) == 1)
@@ -900,6 +1032,11 @@ class LogTopContextMenuConditions:
     def update_to_this_revision(self, data=None):
         return (self.vcs_name == rabbitvcs.vcs.VCS_SVN and len(self.revisions) == 1)
 
+    # TODO Evaluate multiple revisions later
+    # TODO Git?
+    def revert_changes_from_this_revision(self, data=None):
+        return (self.vcs_name == rabbitvcs.vcs.VCS_SVN and len(self.revisions) == 1)
+
     def checkout(self, data=None):
         return (len(self.revisions) == 1)
 
@@ -944,6 +1081,16 @@ class LogTopContextMenuCallbacks:
         self.revisions = revisions
 
         self.vcs_name = self.caller.get_vcs_name()
+
+    def find_parent(self, revision):
+        if ("parents" in revision) and len(revision["parents"]) > 0:
+            parent = unicode(revision["parents"][0])
+        elif ("next_revision" in revision):
+            parent = unicode(revision["next_revision"])
+        else:
+            parent = unicode(int(unicode(revision["revision"])) - 1)
+
+        return parent
         
     def view_diff_working_copy(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("diff", [
@@ -951,11 +1098,11 @@ class LogTopContextMenuCallbacks:
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
+    def copy_clipboard(self, widget, data=None):
+        self.caller.copy_revision_text()
+
     def view_diff_previous_revision(self, widget, data=None):
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "%s@%s" % (self.path, parent),
@@ -987,10 +1134,7 @@ class LogTopContextMenuCallbacks:
         ])
 
     def compare_previous_revision(self, widget, data=None):
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "-s",
@@ -1013,10 +1157,7 @@ class LogTopContextMenuCallbacks:
 
     def show_changes_previous_revision(self, widget, data=None):
         rev_first = unicode(self.revisions[0]["revision"])
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
         
         path = self.path
         if self.vcs_name == rabbitvcs.vcs.VCS_SVN:
@@ -1024,7 +1165,7 @@ class LogTopContextMenuCallbacks:
 
         rabbitvcs.util.helper.launch_ui_window("changes", [
             "%s@%s" % (path, parent),
-            "%s@%s" % (path, unicode(rev_last)),
+            "%s@%s" % (path, unicode(rev_first)),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1048,6 +1189,13 @@ class LogTopContextMenuCallbacks:
             "-r", unicode(self.revisions[0]["revision"]),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
+
+    def revert_changes_from_this_revision(self, widget, data=None):        
+        rabbitvcs.util.helper.launch_ui_window("merge", [
+            self.path,
+            unicode(self.revisions[0]["revision"]) + "-" + str(int(unicode(self.revisions[0]["revision"])) - 1),
+            "--vcs=%s" % self.caller.get_vcs_name()
+        ])        
         
     def checkout(self, widget, data=None):
         url = ""
@@ -1185,7 +1333,7 @@ class LogTopContextMenu:
         # The first element of each tuple is a key that matches a
         # ContextMenuItems item.  The second element is either None when there
         # is no submenu, or a recursive list of tuples for desired submenus.
-        self.structure = [
+        self.structure = [      
             (MenuViewDiffWorkingCopy, None),
             (MenuViewDiffPreviousRevision, None),
             (MenuViewDiffRevisions, None),
@@ -1195,7 +1343,10 @@ class LogTopContextMenu:
             (MenuShowChangesPreviousRevision, None),
             (MenuShowChangesRevisions, None),
             (MenuSeparator, None),
+            (MenuCopyClipboard, None),
+            (MenuSeparator, None),
             (MenuUpdateToThisRevision, None),
+            (MenuRevertChangesFromThisRevision, None),
             (MenuCheckout, None),
             (MenuBranches, None),
             (MenuTags, None),
@@ -1270,13 +1421,20 @@ class LogBottomContextMenuCallbacks:
         self.paths = paths
         self.revisions = revisions
 
+    def find_parent(self, revision):
+        if ("parents" in revision) and len(revision["parents"]) > 0:
+            parent = unicode(revision["parents"][0])
+        elif ("next_revision" in revision):
+            parent = unicode(revision["next_revision"])
+        else:
+            parent = unicode(int(unicode(revision["revision"])) - 1)
+
+        return parent
+
     def view_diff_previous_revision(self, widget, data=None):
         rev = unicode(self.revisions[0]["revision"])
 
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         path_item = self.paths[0]
         url = self.caller.root_url + path_item
@@ -1293,10 +1451,7 @@ class LogBottomContextMenuCallbacks:
     def compare_previous_revision(self, widget, data=None):
         rev = unicode(self.revisions[0]["revision"])
         
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
             
         path_item = self.paths[0]
         url = self.caller.root_url + path_item
@@ -1315,10 +1470,7 @@ class LogBottomContextMenuCallbacks:
     def show_changes_previous_revision(self, widget, data=None):
         rev_first = unicode(self.revisions[0]["revision"])
         
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         url = self.paths[0]
         if self.vcs_name == rabbitvcs.vcs.VCS_SVN:
