@@ -37,9 +37,10 @@ from rabbitvcs import gettext
 _ = gettext.gettext
 
 class SVNMerge(InterfaceView):
-    def __init__(self, path):
+    def __init__(self, path, revision_range = None):
         InterfaceView.__init__(self, "merge", "Merge")
         
+        self.revision_range = revision_range
         
         self.assistant = self.get_widget("Merge")
         
@@ -64,27 +65,36 @@ class SVNMerge(InterfaceView):
         self.assistant.set_forward_page_func(self.on_forward_clicked)
         
         self.repo_paths = rabbitvcs.util.helper.get_repository_paths()
-        
+
         # Keeps track of which stages should be marked as complete
         self.type = None
+
+        self.initialize_root_url()
+
+    def initialize_root_url(self):
+        action = SVNAction(
+            self.svn,
+            notification=False,
+            run_in_thread=False
+        )
+        
+        self.root_url = action.run_single(
+            self.svn.get_repo_url,
+            self.path
+        )
+
+
     #
     # Assistant UI Signal Callbacks
     #
-
-    def on_destroy(self, widget):
-        self.destroy()
     
-    def on_cancel_clicked(self, widget):
-        self.close()
-    
-    def on_close_clicked(self, widget):
-        self.close()
-
     def on_apply_clicked(self, widget):
         self.merge()
     
     def on_test_clicked(self, widget):
-        self.merge(test=True)            
+        self.merge(test=True)    
+
+   
 
     def merge(self, test=False):
         if self.type is None:
@@ -123,9 +133,13 @@ class SVNMerge(InterfaceView):
             ranges = []
             for r in revisions.split(","):
                 if r.find("-") != -1:
-                    (low, high) = r.split("-")
+                    (low, high) = [ int(i) for i in r.split("-") ]
+                    if low < high:
+                        low -= 1
                 elif r.find(":") != -1:
-                    (low, high) = r.split(":")
+                    (low, high) = [ int(i) for i in r.split(":") ]
+                    if low < high:
+                        low -= 1
                 else:
                     high = int(r)
                     low = high - 1
@@ -135,14 +149,14 @@ class SVNMerge(InterfaceView):
                 # Fixed in Pysvn Revision 1114
                 if (self.svn.interface == "pysvn" and self.svn.is_version_less_than((1,6,3,0))):
                     ranges.append((
-                        self.svn.revision("number", number=int(low)).primitive(),
-                        self.svn.revision("number", number=int(high)).primitive(),
+                        self.svn.revision("number", number=low).primitive(),
+                        self.svn.revision("number", number=high).primitive(),
                         None
                     ))
                 else:
                     ranges.append((
-                        self.svn.revision("number", number=int(low)).primitive(),
-                        self.svn.revision("number", number=int(high)).primitive(),
+                        self.svn.revision("number", number=low).primitive(),
+                        self.svn.revision("number", number=high).primitive(),
                     ))
 
             action.append(rabbitvcs.util.helper.save_repository_path, url)
@@ -211,7 +225,8 @@ class SVNMerge(InterfaceView):
                 self.path
             )
             kwargs = {
-                "recurse": recursive
+                "recurse": recursive,
+                "dry_run": test
             }
         
         if len(args) > 0:
@@ -242,6 +257,8 @@ class SVNMerge(InterfaceView):
             if self.get_widget("mergetype_range_opt").get_active():
                 next = 1
                 self.type = "range"
+                if self.revision_range:
+                    self.get_widget("mergerange_revisions").set_text(self.revision_range)
             elif self.get_widget("mergetype_reintegrate_opt").get_active():
                 next = 2
                 self.type = "reintegrate"
@@ -263,15 +280,21 @@ class SVNMerge(InterfaceView):
                 self.get_widget("mergerange_from_urls"), 
                 self.repo_paths
             )
+            self.mergerange_repos.set_child_text(self.root_url)
             self.get_widget("mergerange_working_copy").set_text(self.path)
         
         self.mergerange_check_ready()
         
     def on_mergerange_show_log1_clicked(self, widget):
+        merge_candidate_revisions = self.svn.find_merge_candidate_revisions(
+            self.get_widget("mergerange_from_urls").get_active_text(),
+            self.path
+        )
         SVNLogDialog(
             self.get_widget("mergerange_from_urls").get_active_text(),
             ok_callback=self.on_mergerange_log1_closed, 
-            multiple=True
+            multiple=True,
+            merge_candidate_revisions=merge_candidate_revisions
         )
     
     def on_mergerange_log1_closed(self, data):
@@ -420,12 +443,12 @@ class BranchMerge(InterfaceView):
         self.branch = branch
         self.vcs = rabbitvcs.vcs.VCS()
 
-    def on_destroy(self, widget):
-        self.destroy()
         
     def on_cancel_clicked(self, widget, data=None):
         self.close()
 
+           
+
 class GitMerge(BranchMerge):
     def __init__(self, path, branch=None):
         BranchMerge.__init__(self, path, branch)
@@ -547,11 +570,13 @@ class GitMerge(BranchMerge):
     def __revision_changed(self, widget):
         self.update_branch_info()
 
+           
+
 if __name__ == "__main__":
     from rabbitvcs.ui import main, VCS_OPT
     (options, args) = main(
         [VCS_OPT],
-        usage="Usage: rabbitvcs merge path [revision... (for git)]"
+        usage="Usage: rabbitvcs merge path [revision/revision_range]"
     )
 
     path = args[0]
@@ -561,15 +586,15 @@ if __name__ == "__main__":
         vcs_name = rabbitvcs.vcs.guess(path)["vcs"]    
     
     window = None
+    revision_text = None
+    if len(args) >= 2:
+        revision_text = args[1]
+
     if vcs_name == rabbitvcs.vcs.VCS_SVN:
-        window = SVNMerge(path)
+        window = SVNMerge(path, revision_text)
         window.register_gtk_quit()
         gtk.main()
     elif vcs_name == rabbitvcs.vcs.VCS_GIT:
-        revision1 = None
-        if len(args) == 2:
-            revision1 = args[1]
-
-        window = GitMerge(path, revision1)
+        window = GitMerge(path, revision_text)
         window.register_gtk_quit()
         gtk.main()
