@@ -76,34 +76,53 @@ class GitUpdate(InterfaceView):
             self.get_widget("repository_container"),
             self.git
         )
-
-    def on_destroy(self, widget):
-        self.destroy()
         
-    def on_cancel_clicked(self, widget, data=None):
-        self.close()
+    def on_apply_changes_toggled(self, widget, data=None):
+        self.get_widget("merge").set_sensitive(self.get_widget("apply_changes").get_active())
+        self.get_widget("rebase").set_sensitive(self.get_widget("apply_changes").get_active())
 
     def on_ok_clicked(self, widget, data=None):
         self.hide()
-        merge = self.get_widget("merge").get_active()
+
+        rebase = self.get_widget("rebase").get_active()
+
+        git_function_params = []
+
+        apply_changes = self.get_widget("apply_changes").get_active()
 
         repository = self.repository_selector.repository_opt.get_active_text()
         branch = self.repository_selector.branch_opt.get_active_text()
-    
+        fetch_all = self.get_widget("all").get_active()
+
         self.action = GitAction(
             self.git,
             register_gtk_quit=self.gtk_quit_is_set()
         )
         self.action.append(self.action.set_header, _("Update"))
         self.action.append(self.action.set_status, _("Updating..."))
-        if merge:
-            self.action.append(self.git.pull, repository, branch)
+
+        if not apply_changes:
+            if fetch_all:
+                self.action.append(self.git.fetch, "--all")
+            else:
+                self.action.append(self.git.fetch, repository, branch)
+
         else:
-            self.action.append(self.git.fetch, repository, branch)
+            if rebase:
+                git_function_params.append ("rebase")
+
+            if fetch_all:
+                git_function_params.append ("all")
+                repository = ""
+                branch = ""
+
+            self.action.append(self.git.pull, repository, branch, git_function_params)
+
         self.action.append(self.action.set_status, _("Completed Update"))
         self.action.append(self.action.finish)
         self.action.start()
 
+
 classes_map = {
     rabbitvcs.vcs.VCS_SVN: SVNUpdate, 
     rabbitvcs.vcs.VCS_GIT: GitUpdate
