@@ -68,7 +68,7 @@ _ = gettext.gettext
 
 def get_tmp_path(filename):
     day = datetime.datetime.now().day
-    m = hashlib.md5(str(day)).hexdigest()[0:10]
+    m = hashlib.md5(str(day) + str(os.geteuid())).hexdigest()[0:10]
     
     tmpdir = "/tmp/rabbitvcs-%s" %m
     if not os.path.isdir(tmpdir):
@@ -274,6 +274,22 @@ def get_previous_messages():
     
     return returner
 
+def get_exclude_paths_path():
+    return os.path.join(get_home_folder(), "exclude_paths")
+
+def get_exclude_paths():
+    path = get_exclude_paths_path()
+    if not os.path.exists(path):
+        return []
+        
+    f = open(path, "r")
+    paths = []
+    for l in f:
+        paths.append(l.strip())
+    f.close()
+    
+    return paths
+
 def encode_revisions(revision_array):
     """
     Takes a list of integer revision numbers and converts to a TortoiseSVN-like
@@ -440,7 +456,7 @@ def launch_merge_tool(path1, path2=""):
     if not os.path.exists(diff["path"]):
         return
 
-    os.popen("%s %s %s" % (diff["path"], path1, path2))
+    os.popen("%s '%s' '%s'" % (diff["path"], path1, path2))
     
 def get_file_extension(path):
     """
