@@ -908,7 +908,7 @@ class GittyupClient:
         # Actually move the file/folder
         shutil.move(source, dest)
 
-    def pull(self, repository="origin", refspec="master"):
+    def pull(self, repository="origin", refspec="master", options=None):
         """
         Fetch objects from a remote repository and merge with the local 
             repository
@@ -922,7 +922,18 @@ class GittyupClient:
         """
         self.numberOfCommandStages = 2
 
-        cmd = ["git", "pull","--progress", repository, refspec]
+        cmd = ["git", "pull", "--progress"]
+
+        if options != None:
+            if options.count("rebase"):
+                cmd.append("--rebase")
+
+            if options.count("all"):
+                cmd.append("--all")
+            else:
+                cmd.append (repository)
+                cmd.append (refspec)
+
         try:
             (status, stdout, stderr) = GittyupCommand(cmd, cwd=self.repo.path, notify=self.notify_and_parse_git_pull, cancel=self.get_cancel).execute()
         except GittyupCommandError, e:
@@ -1195,9 +1206,10 @@ class GittyupClient:
         untracked_directories = []
         for line in stdout:
             components = re.match("^(Would remove)\s(.*?)$", line)
-            untracked_path = components.group(2)
-            if untracked_path[-1]=='/':
-                untracked_directories.append(untracked_path[:-1])
+            if components:
+                untracked_path = components.group(2)
+                if untracked_path[-1]=='/':
+                    untracked_directories.append(untracked_path[:-1])
 
         #Determine the ignored files and directories in Repo
         cmd = ["git", "clean", "-ndX", self.repo.path]
@@ -1208,15 +1220,17 @@ class GittyupClient:
         ignored_directories=[]
         for line in stdout:
             components = re.match("^(Would remove)\s(.*?)$", line)
-            ignored_path=components.group(2)
-            if ignored_path[-1]=='/':
-                ignored_directories.append(ignored_path[:-1])
-                next
-            statuses.append(IgnoredStatus(ignored_path))
-            try:
-                del files_hash[ignored_path]
-            except Exception, e:
-                pass
+            if components:
+                ignored_path=components.group(2)
+                if ignored_path[-1]=='/':
+                    ignored_directories.append(ignored_path[:-1])
+                    next
+                statuses.append(IgnoredStatus(ignored_path))
+                self.ignored_paths.append(ignored_path)
+                try:
+                    del files_hash[ignored_path]
+                except Exception, e:
+                    pass
         for file,data in files_hash.items():
             ignore_file=False
             untracked_file=False
@@ -1230,8 +1244,11 @@ class GittyupClient:
                     break
             if untracked_file==True:
                 statuses.append(UntrackedStatus(file))
+                if ignore_file==True:
+                    self.ignored_paths.append(file)
             elif ignore_file==True:
                 statuses.append(IgnoredStatus(file))
+                self.ignored_paths.append(file)
             else:
                 statuses.append(NormalStatus(file))
 
@@ -1336,6 +1353,8 @@ class GittyupClient:
             
             if not self._ignore_file(patterns, os.path.basename(name)):
                 statuses.append(UntrackedStatus(name))
+            else:
+                self.ignored_paths.append(name)
 
         # Determine status of folders based on child contents
         for d in directories:
@@ -1350,7 +1369,13 @@ class GittyupClient:
 
         return statuses
 
+    def get_all_ignore_file_paths(self, path):
+        return self.ignored_paths
+
+
     def status(self, path):
+        # TODO - simply get this from the status implementation / avoid global state
+        self.ignored_paths = []
         version = self._get_git_version()
         if version and self._version_greater_than(version, [1,7,-1]):
             return self.status_porcelain(path)
