@@ -24,6 +24,8 @@
 Concrete VCS implementation for Subversion functionality.
 """
 import subprocess
+import os
+import shutil
 import os.path
 from os.path import isdir, isfile, dirname, islink, realpath
 from datetime import datetime
@@ -66,15 +68,22 @@ class Revision:
         self.value = value
         self.is_revision_object = True
 
+        # TODO Shift to options factory?
+        if self.value and str(self.value).lower().strip() == 'head':
+            self.kind = "head"
+
         if self.value is None and self.kind in ("number", "date"):
             self.kind = "head"
 
+        if self.kind == "head":
+            self.value = None
+
         self.__revision_kind = self.KINDS[self.kind]
         self.__revision = None
 
         try:
-            if value is not None:
-                self.__revision = pysvn.Revision(self.__revision_kind, value)
+            if self.value is not None:
+                self.__revision = pysvn.Revision(self.__revision_kind, self.value)
             else:
                 self.__revision = pysvn.Revision(self.__revision_kind)
         except Exception, e:
@@ -342,11 +351,14 @@ class SVN:
         if self.is_working_copy(path):
             return True
         else:
-            # info will return nothing for an unversioned file inside a working copy
-            if (self.is_in_a_or_a_working_copy(path) and
-                    self.client_info(path)):
-                return True
-
+            try:
+                # info will return nothing for an unversioned file inside a working copy
+                if (self.is_in_a_or_a_working_copy(path) and
+                        self.client_info(path)):
+                    return True
+            except Exception, e:
+                log.exception("is_versioned exception for %s" % path)
+                
             return False
 
     def is_status(self, path, status_kind):
@@ -537,6 +549,49 @@ class SVN:
 
         return returner
 
+    def find_merge_candidate_revisions(self, from_url, to_path):
+        """
+        Return the list of revisions from from_url that are not already merged into to_path.
+
+        @type  from_url:  string
+        @param from_url:  A repository URL to merge from.
+
+        @type  to_path:   string
+        @param to_path:   A working copy path to merge into.
+
+        @rtype:           list
+        @return:          A list of revisions not already merged.
+        """
+
+        from_url_root = self.get_repo_root_url(from_url)
+        from_branch = from_url.replace(from_url_root, '')
+        from_branch = from_branch.rstrip('/')
+
+        merge_info = self.propget(to_path, "svn:mergeinfo")
+
+        merged_revisions = []
+        for branch in merge_info.split('\n'):
+            if not branch.startswith(from_branch + ':'):
+                continue
+            revisions = branch.split(':')[1]  # branch:rev,rev-rev,...
+            for rev in revisions.split(','):
+                if rev.find('-') != -1:
+                    (rev_s, rev_e) = rev.split('-')
+                    merged_revisions += range(int(rev_s), int(rev_e) + 1)
+                else:
+                    merged_revisions.append(int(rev))
+
+        from_log = self.log(from_url, strict_node_history=False)
+        from_revisions = [ int(l.revision.short()) for l in from_log ]
+
+        to_log = self.log(to_path, strict_node_history=False)
+        to_revisions = [ int(l.revision.short()) for l in to_log ]
+
+        candidate_revisions = list(set(from_revisions) - set(to_revisions) - set(merged_revisions))
+
+        return candidate_revisions
+
+
     #
     # properties
     #
@@ -1182,7 +1237,14 @@ class SVN:
         @param  recurse: Whether or not to run a recursive checkout.
 
         """
-        
+        if os.path.exists(dest_path):
+            if os.path.isdir(dest_path):
+                shutil.rmtree(dest_path)
+            else:
+                os.remove(dest_path)
+
+
+
         return self.client.export(src_url_or_path, dest_path, force,
             revision.primitive(), native_eol, ignore_externals, recurse)
 
