@@ -18,12 +18,12 @@ rm -rf templates
 
 for mo in `ls`;
 do
-    if [ -f ../../rabbitvcs/locale/$mo/LC_MESSAGES/RabbitVCS.mo ];
+    if [ -f ../../locale/$mo/LC_MESSAGES/RabbitVCS.mo ];
     then
-        mv $mo/LC_MESSAGES/* ../../rabbitvcs/locale/$mo/LC_MESSAGES/RabbitVCS.mo
+        mv $mo/LC_MESSAGES/* ../../locale/$mo/LC_MESSAGES/RabbitVCS.mo
     else
-        mkdir -p ../../rabbitvcs/locale/$mo/LC_MESSAGES
-        mv $mo/LC_MESSAGES/rabbit-vcs.mo ../../rabbitvcs/locale/$mo/LC_MESSAGES/RabbitVCS.mo
+        mkdir -p ../../locale/$mo/LC_MESSAGES
+        mv $mo/LC_MESSAGES/rabbit-vcs.mo ../../locale/$mo/LC_MESSAGES/RabbitVCS.mo
     fi
 done
 
